/***
 * Juliac
 * Copyright (C) 2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac.opt.ultracomp;

import org.objectweb.fractal.api.type.InterfaceType;
import org.objectweb.fractal.juliac.desc.MembraneDesc;

/**
 * Composite interceptor component type generator.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.5
 */
public class CompositeInterceptorComponentTypeGenerator
implements InterceptorComponentTypeGeneratorItf {
	
	private InterceptorComponentTypeGeneratorItf[] subs;
	
	public CompositeInterceptorComponentTypeGenerator(
		InterceptorComponentTypeGeneratorItf[] subs ) {
		this.subs = subs;
	}

	public InterfaceType[]
		match( InterfaceType it, MembraneDesc<?> membraneDesc ) {
		
		InterfaceType[] array = null;
		
		for( InterceptorComponentTypeGeneratorItf elt : subs ) {
			InterfaceType[] its = elt.match(it,membraneDesc);
			if( its != null ) {
				if( array == null ) {
					array = its;
				}
				else {
					InterfaceType[] old =
						new InterfaceType[ array.length + its.length ];
					System.arraycopy(array,0,old,0,array.length);
					System.arraycopy(its,0,old,array.length,its.length);
					array = old;
				}
			}
		}
		
		return array;
	}
}
