/***
 * Juliac
 * Copyright (C) 2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac.opt.ultracomp;

import org.objectweb.fractal.api.type.InterfaceType;
import org.objectweb.fractal.juliac.desc.MembraneDesc;

/**
 * Interface for interceptor component type generators.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.5
 */
public interface InterceptorComponentTypeGeneratorItf {

	/**
	 * Return the type of the interceptor component for the specified interface
	 * type and membrane descriptor. Return <code>null</code> if no interceptor
	 * component is needed.
	 * 
	 * @param it            the interface type
	 * @param membraneDesc  the membrane descriptor
	 * @return  the type of the interceptor component or <code>null</code>
	 */
	public InterfaceType[]
		match( InterfaceType it, MembraneDesc<?> membraneDesc );
}
